@@ -27,10 +27,6 @@ dsiNMF <- function(X, M=NULL, pseudocount=.Machine$double.eps,
     TrainRecError <- int$TrainRecError
     TestRecError <- int$TestRecError
     RelChange <- int$RelChange
-    BinTerm_W <- int$BinTerm_W
-    BinTerm_H <- int$BinTerm_H
-    TerTerm_W <- int$TerTerm_W
-    TerTerm_H <- int$TerTerm_H
     p <- int$p
     iter <- 1
     while ((RecError[iter] > thr) && (iter <= num.iter)) {
@@ -82,10 +78,6 @@ dsiNMF <- function(X, M=NULL, pseudocount=.Machine$double.eps,
             .recError((M_NA[[x]]-M[[x]])*X[[x]], (M_NA[[x]]-M[[x]])*X_bar[[x]], notsqrt=TRUE)
         }))))
         RelChange[iter] <- abs(pre_Error - RecError[iter]) / RecError[iter]
-        BinTerm_W[iter] <- .BinTerm_W_dsiNMF(W)
-        BinTerm_H[iter] <- .BinTerm_H_dsiNMF(H)
-        TerTerm_W[iter] <- .TerTerm_W_dsiNMF(W)
-        TerTerm_H[iter] <- .TerTerm_H_dsiNMF(H)
         # Visualization
         if (viz && !is.null(figdir)) {
             png(filename = paste0(figdir, "/", iter-1, ".png"))
@@ -119,19 +111,11 @@ dsiNMF <- function(X, M=NULL, pseudocount=.Machine$double.eps,
     names(TrainRecError) <- c("offset", seq_len(iter-1))
     names(TestRecError) <- c("offset", seq_len(iter-1))
     names(RelChange) <- c("offset", seq_len(iter-1))
-    names(BinTerm_W) <- c("offset", seq_len(iter-1))
-    names(BinTerm_H) <- c("offset", seq_len(iter-1))
-    names(TerTerm_W) <- c("offset", seq_len(iter-1))
-    names(TerTerm_H) <- c("offset", seq_len(iter-1))
     list(W = W, H = H,
         RecError = RecError,
         TrainRecError = TrainRecError,
         TestRecError = TestRecError,
-        RelChange = RelChange,
-        BinTerm_W = BinTerm_W,
-        BinTerm_H = BinTerm_H,
-        TerTerm_W = TerTerm_W,
-        TerTerm_H = TerTerm_H)
+        RelChange = RelChange)
 }
 
 .checkdsiNMF <- function(X, M, pseudocount, initW, initH, fixW, fixH, Bin_W, Bin_H, Ter_W, Ter_H, L1_W, L1_H, L2_W, L2_H, J, w,
@@ -249,18 +233,10 @@ dsiNMF <- function(X, M=NULL, pseudocount=.Machine$double.eps,
     TrainRecError = c()
     TestRecError = c()
     RelChange = c()
-    BinTerm_W = c()
-    BinTerm_H = c()
-    TerTerm_W = c()
-    TerTerm_H = c()
     RecError[1] <- thr * 10
     TrainRecError[1] <- thr * 10
     TestRecError[1] <- thr * 10
     RelChange[1] <- thr * 10
-    BinTerm_W[1] <- thr * 10
-    BinTerm_H[1] <- thr * 10
-    TerTerm_W[1] <- thr * 10
-    TerTerm_H[1] <- thr * 10
     # Algorithm
     if (algorithm == "Frobenius") {
         p = 0
@@ -281,8 +257,6 @@ dsiNMF <- function(X, M=NULL, pseudocount=.Machine$double.eps,
         fixH=fixH, w=w, K=K,
         W=W, H=H, RecError=RecError, TrainRecError=TrainRecError,
         TestRecError=TestRecError, RelChange=RelChange,
-        BinTerm_W=BinTerm_W, BinTerm_H=BinTerm_H,
-        TerTerm_W=TerTerm_W, TerTerm_H=TerTerm_H,
         p=p)
 }
 
@@ -297,22 +271,3 @@ dsiNMF <- function(X, M=NULL, pseudocount=.Machine$double.eps,
     })
 }
 
-.BinTerm_W_dsiNMF <- function(W){
-    sum((W * (W - 1))^2)
-}
-
-.BinTerm_H_dsiNMF <- function(H){
-    do.call(sum, lapply(H, function(h){
-        sum((h * (h - 1))^2)
-    }))
-}
-
-.TerTerm_W_dsiNMF <- function(W){
-    sum((W * (W - 1) * (W - 2))^2)
-}
-
-.TerTerm_H_dsiNMF <- function(H){
-    do.call(sum, lapply(H, function(h){
-        sum((h * (h - 1) * (h - 2))^2)
-    }))
-}
